/* MyView - Custom view.

   Copyright (C) 2000 Free Software Foundation, Inc.

   Author:  Adam Fedor <fedor@gnu.org>
   Date: Feb 2000
   
   This file is part of GNUstep.
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */

#include "MyView.h"

@implementation MyView

- (NSImage *) compositeImage
{
  NSRect frame;
  if (comp)
    return comp;

  frame = NSMakeRect(0, 0, 100, 100);
  comp = [[NSImage alloc] initWithSize: frame.size];		
			
  [comp lockFocus];
			
  [[NSColor clearColor] set];
  NSRectFill (frame);

  [comp unlockFocus];
  return comp;
		
}

- (void)orderFront:(id)sender
{
  [[self window] orderFront: sender];
  NSLog(@"Done");
}

- (void)orderFrontRegardless: (id)sender
{
  [[self window] orderFrontRegardless];
  NSLog(@"Done");
}

- (void)orderRelative: (id)sender
{
  [[self window] orderWindow: NSWindowAbove relativeTo: 0];
  NSLog(@"Done");
}

- (void) mouseDown: sender
{
  SEL sel;
  NSTimer *timer;
  NSRect ll, lr, ul, ur;
  NSPoint location = [sender locationInWindow];
  location = [self convertPoint: location  fromView: nil];

  NSDivideRect([self frame], &ll, &lr, 200, NSMaxXEdge);
  NSDivideRect(ll, &ll, &ul, 200, NSMaxYEdge);
  NSDivideRect(lr, &lr, &ur, 200, NSMaxYEdge);

  [super mouseDown: sender];
  NSLog(@"Mouse down at %@", NSStringFromPoint(location));

  if ([self mouse: location inRect: ll])
    {
      sel = @selector(orderFront:);
    }
  else if ([self mouse: location inRect: lr])
    {
      sel = @selector(orderFrontRegardless:);
    }
  else if ([self mouse: location inRect: ul])
    {
      sel = @selector(orderRelative:);
    }
  else if ([self mouse: location inRect: ur])
    {
      sel = @selector(orderFront:);
    }
  timer = [NSTimer scheduledTimerWithTimeInterval: 10 
		target: self
		selector: sel
		userInfo: self
		repeats: NO];
  NSLog(@"Schedulded timer to open window with %@", NSStringFromSelector(sel));
}  
   
- (void) drawRect: (NSRect)rect
{
  NSRect ll, lr, ul, ur;

  NSDivideRect([self frame], &ll, &lr, 200, NSMaxXEdge);
  NSDivideRect(ll, &ll, &ul, 200, NSMaxYEdge);
  NSDivideRect(lr, &lr, &ur, 200, NSMaxYEdge);
  NSLog(@"Drawing rects\n %@\n %@\n %@\n %@", NSStringFromRect(ll), 
    NSStringFromRect(lr), NSStringFromRect(ul), NSStringFromRect(ur));
  
  [[NSColor redColor] set];
  NSRectFill (ll);
  [[NSColor greenColor] set];
  NSRectFill (lr);
  [[NSColor blueColor] set];
  NSRectFill (ul);
  [[NSColor redColor] set];
  NSRectFill (ur);
}

@end
